==> owncloud-app-contacts-2%3A1.3.1.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/nl.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contactpersonen",
    "Address book name" : "Adresboek naam",
    "Import" : "Importeer",
    "No contacts in here" : "Hier geen contactpersonen gevonden",
    "Name" : "Naam",
    "Organization" : "Organisatie",
    "Title" : "Titel",
    "Add field ..." : "Voeg veld toe",
    "Add contact" : "Contactpersoon toevoegen",
    "No search result for {query}" : "Geen zoekresultaten voor {query}",
    "All contacts" : "Alle contactpersonen",
    "Not grouped" : "Niet gegroepeerd",
    "Post Office Box" : "Postbus",
    "Postal Code" : "Postcode",
    "City" : "Stad",
    "State or province" : "Staat of provincie",
    "Country" : "Land",
    "Address" : "Adres",
    "(new group)" : "(nieuwe groep)",
    "New contact" : "Nieuwe contactpersoon",
    "{addressbook} shared by {owner}" : "{addressbook} gedeeld door {owner}",
    "No contacts in file. Only VCard files are allowed." : "Geen contacten in bestand. Alleen VCard bestanden zijn toegestaan.",
    "Nickname" : "Roepnaam",
    "Notes" : "Notities",
    "Website" : "Website",
    "Federated Cloud ID" : "Gefedereerde Cloud ID",
    "Home" : "Thuis",
    "Work" : "Werk",
    "Other" : "Overig",
    "Groups" : "Groepen",
    "Birthday" : "Verjaardag",
    "Email" : "mailadres",
    "Instant messaging" : "Instant messaging",
    "Phone" : "Telefoon",
    "Mobile" : "Mobiel",
    "Fax" : "Fax",
    "Fax home" : "Fax thuis",
    "Fax work" : "Fax werk",
    "Pager" : "Pieper",
    "Voice" : "Stem",
    "Social Network" : "Sociaal Netwerk",
    "Settings" : "Instellingen"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-contacts-2%3A1.4.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/nl.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contactpersonen",
    "Address book name" : "Adresboek naam",
    "Import" : "Importeer",
    "The selected image is too big (max 1MB)" : "De geselecteerde afbeelding is te groot (max 1MB)",
    "No contacts in here" : "Hier geen contactpersonen gevonden",
    "Name" : "Naam",
    "Organization" : "Organisatie",
    "Title" : "Titel",
    "Add field ..." : "Voeg veld toe",
    "+ New contact" : "+ Nieuwe contactpersoon",
    "No search result for {query}" : "Geen zoekresultaten voor {query}",
    "_%n contact_::_%n contacts_" : ["%n contactpersoon","%n contactpersonen"],
    "Post office box" : "Postbus",
    "Postal code" : "Postcode",
    "City" : "Stad",
    "State or province" : "Staat of provincie",
    "Country" : "Land",
    "Address" : "Adres",
    "(new group)" : "(nieuwe groep)",
    "Last name" : "Achternaam",
    "First name" : "Voornaam",
    "Additional names" : "Extra namen",
    "Prefix" : "Voorvoegsel",
    "Suffix" : "Achtervoegsel",
    "All contacts" : "Alle contactpersonen",
    "Not grouped" : "Niet gegroepeerd",
    "New contact" : "Nieuwe contactpersoon",
    "{addressbook} shared by {owner}" : "{addressbook} gedeeld door {owner}",
    "No contacts in file. Only VCard files are allowed." : "Geen contacten in bestand. Alleen VCard bestanden zijn toegestaan.",
    "Nickname" : "Roepnaam",
    "Detailed name" : "Gedetailleerde naam",
    "Notes" : "Notities",
    "Website" : "Website",
    "Federated Cloud ID" : "Gefedereerde Cloud ID",
    "Home" : "Thuis",
    "Work" : "Werk",
    "Other" : "Overig",
    "Groups" : "Groepen",
    "Birthday" : "Verjaardag",
    "Anniversary" : "Verjaardag",
    "Date of death" : "Overlijdensdatum",
    "Email" : "mailadres",
    "Instant messaging" : "Instant messaging",
    "Phone" : "Telefoon",
    "Mobile" : "Mobiel",
    "Fax" : "Fax",
    "Fax home" : "Fax thuis",
    "Fax work" : "Fax werk",
    "Pager" : "Pieper",
    "Voice" : "Stem",
    "Social network" : "Social network",
    "Settings" : "Instellingen"
},
"nplurals=2; plural=(n != 1);");
